---
name: Bug report
about: Create a report to help improve {{ cookiecutter.project_name }}
title: ''
labels: 'bug'
assignees: ''
---

**Describe the bug**  
A clear and concise description of what the bug is.

**To Reproduce**  
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '...'
3. Scroll down to '...'
4. See error

**Expected behavior**  
A clear and concise description of what you expected to happen.

**Screenshots**  
If applicable, add screenshots to help explain your problem.

**Environment**
- OS: [e.g. macOS, Windows, Ubuntu]
- Python version: [e.g. 3.11]
- Version of {{ cookiecutter.project_slug }}: [e.g. 0.1.0]

**Additional context**  
Add any other context about the problem here.
